@@ -1,5 +1,3 @@
-from typing import Union
-
 from evmosproto.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest
 from evmosproto.cosmos.auth.v1beta1.query_pb2_grpc import QueryStub
 from evmosproto.ethermint.types.v1.account_pb2 import EthAccount
@@ -9,7 +7,7 @@ from evmosgrpc.utils import create_grpc_channel
 
 
 # Get account, returns pub_key, account_number, sequence
-def get_account_grpc(account: str) -> Union[tuple[str, str], tuple[None, None]]:
+def get_account_grpc(account: str):
     # Create channel
     stub = QueryStub(create_grpc_channel())
     params = QueryAccountRequest()
@@ -20,4 +18,9 @@ def get_account_grpc(account: str) -> Union[tuple[str, str], tuple[None, None]]:
     account = EthAccount()
     account.ParseFromString(resp.account.value)
     account = MessageToDict(account, including_default_value_fields=True)['baseAccount']
-    return account['accountNumber'], account['sequence']
+
+    pubkey = None
+    if 'pubKey' in account:
+        pubkey = account['pubKey']['key']
+
+    return account['accountNumber'], account['sequence'], pubkey
